//
//  Package: OpenDialog.sl
//  Author:  David Martinko
//  Company: Redeemed Software www.redeemedsoftware.com
//  Purpose: Easliy attach either a file or directory dialog to
//          either a form object or a database field.
//
//  OpenFileDialog Notes:
//      The file dialog calls the prompt_callback so you can set
//      properties of the file dialog.
//
//      Object oForm1 is a Form
//          Set Prompt_Object to (oOpenFileDialog_sl(Self))
//          // Set properties of the OpenDialog
//          Procedure Prompt_Callback handle hoPrompt
//              Set Filter_String  of hoPrompt To 'Source|*.src|Include Files|*.inc|Packages|*.pkg|All Source|*.src;*.pkg;*.inc'
//              Set Initial_Folder of hoPrompt To 'C:\Program Files\Visual DataFlex 11.1'
//              Set Filter_Index   of hoPrompt To 2
//          End_Procedure // Prompt_Callback
//      End_Object // oForm1
//
//
//  OpenFolderDialog Notes:
//      The folder dialog does not have any properties to set
//      it just returns a selected path so this object does
//      not call Prompt_Callback.
//
//
//  Usage:  Use it just like you would a selection list. You can
//      You can use it in a Datadictionary for fields.
//
//  Thanks to: Wil van Antwerpen (Antwise Solutions) for the 
//      vWin32fh.pkg which makes the OpenDirectoryDialog possible.
//
//  09/17/06 DMM - Created
//  09/18/06 DMM - Changed state of data-bound fields was not being set. Fixed.
Use File_dlg.Pkg
Use vWin32fh.pkg // visit "http://www.vdf-guidance.com" for this package.

Cd_Popup_Object oOpenFileDialog_sl Is a ModalPanel
    Set Size to 10 35
    Property Handle phoOpenDialog 0
    
    Object CustomOpenDialog is a OpenDialog
        Set phoOpenDialog to (Self)
        Set NoChangeDir_State to TRUE
    End_Object // CustomOpenDialog
    
    Procedure Popup
        String sPath
        Handle Invoking_Object_ID
        Boolean bOpen IsDeoControl
        
        Move (focus(desktop)) To Invoking_Object_ID
        Get value Of Invoking_Object_ID Item current To sPath
        Set Initial_Folder of (phoOpenDialog(Self)) to sPath
        Send Prompt_Callback of Invoking_Object_ID (phoOpenDialog(Self))
        Get Show_Dialog of (phoOpenDialog(Self)) To bOpen
        If (bOpen) Begin
            Get is_Function Get_DEO_Control_Object Invoking_Object_ID False to IsDeoControl
            If (IsDeoControl) Begin
                Set File_Field_Changed_State of (Server(Invoking_Object_ID)) (Data_File(Invoking_Object_ID)) (Data_Field(Invoking_Object_ID)) to TRUE
            End
            Set Value of Invoking_Object_ID item Current to (File_name(phoOpenDialog(Self)))
        End
    End_Procedure // Popup
Cd_End_Object    // oOpenFileDialog_sl

Cd_Popup_Object oOpenFolderDialog_sl Is a ModalPanel
    Procedure Popup
        String sPath
        Handle Invoking_Object_ID
        Boolean IsDeoControl
        
        Move (focus(desktop)) To Invoking_Object_ID
        Get vSHBrowseForFolder "Select a Directory" to sPath
        If (sPath<>"") Begin
            Get is_Function Get_DEO_Control_Object Invoking_Object_ID False to IsDeoControl
            If (IsDeoControl) Begin
                Set File_Field_Changed_State of (Server(Invoking_Object_ID)) (Data_File(Invoking_Object_ID)) (Data_Field(Invoking_Object_ID)) to TRUE
            End
            Set Value of Invoking_Object_ID item Current to sPath
        End
    End_Procedure // Popup
Cd_End_Object    // oOpenFolderDialog_sl